@@ -2,7 +2,7 @@
 
 use std::path::PathBuf;
 
-use clap::{arg, builder::ArgAction, command, ArgGroup, Parser};
+use clap::{builder::ArgAction, ArgGroup, Parser};
 
 use crate::types::{ColorOptions, PlatformType};
 
@@ -32,6 +32,14 @@ pub(crate) struct Cli {
     #[arg(short = 'l', long = "list")]
     pub list: bool,
 
+    /// Edit custom page with `EDITOR`
+    #[arg(long, requires = "command")]
+    pub edit_page: bool,
+
+    /// Edit custom patch with `EDITOR`
+    #[arg(long, requires = "command", conflicts_with = "edit_page")]
+    pub edit_patch: bool,
+
     /// Render a specific markdown file
     #[arg(
         short = 'f',
@@ -66,6 +74,10 @@ pub(crate) struct Cli {
     #[arg(short = 'c', long = "clear-cache")]
     pub clear_cache: bool,
 
+    /// Override config file location
+    #[arg(long = "config-path", value_name = "FILE")]
+    pub config_path: Option<PathBuf>,
+
     /// Use a pager to page output
     #[arg(long = "pager", requires = "command_or_file")]
     pub pager: bool,
