@@ -69,9 +69,10 @@ pub fn print_page(
             LineIterator::new(reader),
             &mut process_snippet,
             !config.display.compact,
+            config.display.show_title,
         )
         .context("Could not write to stdout")?;
-    };
+    }
 
     // We're done outputting data, flush stdout now!
     handle.flush().context("Could not flush stdout")?;
@@ -92,6 +93,7 @@ fn print_snippet(
         NormalCode(s) => write!(writer, "{}", s.paint(style.example_code)),
         Description(s) => writeln!(writer, "  {}", s.paint(style.description)),
         Text(s) => writeln!(writer, "  {}", s.paint(style.example_text)),
+        Title(s) => writeln!(writer, "  {}", s.paint(style.command_name)),
         Linebreak => writeln!(writer),
     }
 }
